@@ -5,7 +5,6 @@ import sunday.core.paths as paths
 from http.cookiejar import LWPCookieJar, CookieJar
 from sunday.core.getEnv import getEnv
 from sunday.core.logger import Logger
-from sunday.core.common import exit
 from sunday.core.checkPacNet import checkPacNet
 from sunday.core.getConfig import getConfig
 from sunday.core.enver import enver
@@ -14,6 +13,7 @@ from pypac import PACSession
 from requests.auth import HTTPProxyAuth
 from sunday.core.globalvar import getvar, setvar
 from sunday.core.globalKeyMaps import sdvar_exception
+from pydash import omit
 
 # 关闭由verify=False引起的提示
 requests.packages.urllib3.disable_warnings()
@@ -104,13 +104,14 @@ class Fetch():
     def requestByType(self, type, times, *args, **kwargs):
         try:
             stime = time.time()
-            logger.debug('fetching %s %s' % (args, kwargs))
-            res = getattr(self.session, type)(*args, **kwargs)
+            params = omit(kwargs, ['timeout_time'])
+            logger.debug('fetching %s %s' % (args, params))
+            res = getattr(self.session, type)(*args, timeout=15, **params)
             logger.info('fetch result %s (状态: %d, 用时: %.3f)' % (res.url, res.status_code, time.time() - stime))
             return res
         except Exception as e:
-            if times >= 3:
-                exit('第%d次尝试失败, 请检查网络后重试!' % times)
+            if times >= kwargs.get('timeout_time', 3):
+                raise getvar(sdvar_exception)(-1, '第%d次尝试失败, 请检查网络后重试!' % times)
             times += 1
             logger.warning('接口请求失败, 进行第%d次尝试: %s' % (times, e))
             return self.requestByType(type, times, *args, **kwargs)
