@@ -7,7 +7,7 @@ from os import path
 from sunday.core.globalvar import getvar, setvar
 from sunday.core.getConfig import getConfig
 import sunday.core.paths as paths
-from sunday.core.globalKeyMaps import sdvar_loggerid, sdvar_logger
+from sunday.core.globalKeyMaps import sdvar_loggerid, sdvar_logger, sdvar_loglevel
 
 if not getvar(sdvar_loggerid):
     loggerId = datetime.datetime.today().isoformat()
@@ -17,6 +17,8 @@ if not getvar(sdvar_loggerid):
         def exitPrintLogfile():
             getvar(sdvar_logger).info('LOG FILE AT: %s' % path.join(paths.logCwd, loggerId))
 
+logLevelKeys = ['notset', 'debug', 'info', 'warning', 'error', 'critical']
+
 logfile = path.join(paths.logCwd, getvar(sdvar_loggerid))
 
 logging.basicConfig(filename=logfile, level=logging.DEBUG, force=True,
@@ -27,7 +29,8 @@ class Logger():
         cfg = getConfig('LOGGING')
         logger = logging.getLogger(name)
         if not logger.handlers:
-            logger.setLevel(logging.getLevelName(level or cfg('level')))
+            loglevel = level or getvar(sdvar_loglevel) or cfg('level') or 'error'
+            logger.setLevel(logging.getLevelName(loglevel.upper()))
             loghd = logging.StreamHandler()
             loghd.setFormatter(colorlog.ColoredFormatter(format or cfg('format'), datefmt='%H:%M:%S'))
             logger.addHandler(loghd)
@@ -36,3 +39,13 @@ class Logger():
 
     def getLogger(self):
         return self.logger
+
+def setLogLevel(level):
+    # 设置所有日志管理者的日志等级
+    setvar(sdvar_loglevel, level)
+    levelstr = level.upper()
+    level = getattr(logging, levelstr)
+    handlerList = logging.Logger.manager.loggerDict.values()
+    for handler in handlerList:
+        if hasattr(handler, 'setLevel') and handler.level != level:
+            handler.setLevel(level)
